package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.AdmEmsIndexRange;

import java.util.List;
import java.util.Map;

/**
 * 能源指标范围Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-30
 */
public interface AdmEmsIndexRangeMapper {
    /**
     * 查询能源指标范围
     *
     * @param id 能源指标范围主键
     * @return 能源指标范围
     */
    AdmEmsIndexRange selectAdmEmsIndexRangeById(Long id);

    /**
     * 查询能源指标范围列表
     *
     * @param indexRange 能源指标范围
     * @return 能源指标范围集合
     */
    List<AdmEmsIndexRange> selectAdmEmsIndexRangeList(AdmEmsIndexRange indexRange);

    /**
     * 新增能源指标范围
     *
     * @param indexRange 能源指标范围
     * @return 结果
     */
    int insertAdmEmsIndexRange(AdmEmsIndexRange indexRange);

    /**
     * 修改能源指标范围
     *
     * @param indexRange 能源指标范围
     * @return 结果
     */
    int updateAdmEmsIndexRange(AdmEmsIndexRange indexRange);

    /**
     * 删除能源指标范围
     *
     * @param id 能源指标范围主键
     * @return 结果
     */
    int deleteAdmEmsIndexRangeById(Long id);

    /**
     * 批量删除能源指标范围
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteAdmEmsIndexRangeByIds(Long[] ids);

    List<Map<String, Object>> selectAdmEmsIndexRange();
}
