package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.AdmEmsIndexRange;
import com.ruoyi.ems.service.IAdmEmsIndexRangeService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 能源指标范围Controller
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/ems/indexRange")
@Api(value = "AdmEmsIndexRangeController", description = "能源指标范围")
public class AdmEmsIndexRangeController extends BaseController
{
    @Autowired
    private IAdmEmsIndexRangeService indexRangeService;

    /**
     * 查询能源指标范围列表
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdmEmsIndexRange indexRange)
    {
        startPage();
        List<AdmEmsIndexRange> list = indexRangeService.selectAdmEmsIndexRangeList(indexRange);
        return getDataTable(list);
    }

    /**
     * 导出能源指标范围列表
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:export')")
    @Log(title = "能源指标范围", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmEmsIndexRange indexRange)
    {
        List<AdmEmsIndexRange> list = indexRangeService.selectAdmEmsIndexRangeList(indexRange);
        ExcelUtil<AdmEmsIndexRange> util = new ExcelUtil<AdmEmsIndexRange>(AdmEmsIndexRange.class);
        util.exportExcel(response, list, "能源指标范围数据");
    }

    /**
     * 获取能源指标范围详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(indexRangeService.selectAdmEmsIndexRangeById(id));
    }

    /**
     * 新增能源指标范围
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:add')")
    @Log(title = "能源指标范围", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmEmsIndexRange indexRange)
    {
        return toAjax(indexRangeService.insertAdmEmsIndexRange(indexRange));
    }

    /**
     * 修改能源指标范围
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:edit')")
    @Log(title = "能源指标范围", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmEmsIndexRange indexRange)
    {
        return toAjax(indexRangeService.updateAdmEmsIndexRange(indexRange));
    }

    /**
     * 删除能源指标范围
     */
    @PreAuthorize("@ss.hasPermi('ems:indexRange:remove')")
    @Log(title = "能源指标范围", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(indexRangeService.deleteAdmEmsIndexRangeByIds(ids));
    }
}
